import { getAllBackgroundsByProjectId } from '@/redux/backgrounds/backgrounds.thunks';
import { useAppDispatch } from '@/redux/hooks/useAppDispatch';
import { getAllModelsByProjectId } from '@/redux/models/models.thunks';
import { getAllPublicOverlaysByProjectId } from '@/redux/overlays/overlays.thunks';
import { projectDataSelector } from '@/redux/project/project.selectors';
import {
  mapLoadingFirstStageCompletedSelector,
  mapLoadingSecondStageInitializedSelector,
} from '@/redux/root/mapStages.selectors';
import { AppDispatch } from '@/redux/store';
import { Project } from '@/types/models';
import { useCallback, useEffect } from 'react';
import { useSelector } from 'react-redux';

const getMapDataAction =
  (project: Project) =>
    (dispatch: AppDispatch): void => {
      dispatch(getAllBackgroundsByProjectId(project.projectId));
      dispatch(getAllPublicOverlaysByProjectId(project.projectId));
      dispatch(getAllModelsByProjectId(project.projectId));
    };

export const useSecondStage = (): void => {
  const dispatch = useAppDispatch();
  const project = useSelector(projectDataSelector);
  const isPreviousCompleted = useSelector(mapLoadingFirstStageCompletedSelector);
  const isInitialized = useSelector(mapLoadingSecondStageInitializedSelector);

  const initMapData = useCallback((): void => {
    if (!project) {
      return;
    }

    dispatch(getMapDataAction(project));
  }, [dispatch, project]);

  useEffect(() => {
    if (!isPreviousCompleted || isInitialized) {
      return;
    }

    initMapData();
  }, [initMapData, isInitialized, isPreviousCompleted]);
};
