import { backgroundsDataSelector } from '@/redux/backgrounds/background.selectors';
import { mapDataSelector } from '@/redux/map/map.selectors';
import { modelsDataSelector } from '@/redux/models/models.selectors';
import { mapLoadingAllStagesCompletedSelector } from '@/redux/root/mapStages.selectors';
import { useHandleMapChange } from '@/utils/map/useHandleMapChange';
import { useCallback, useEffect } from 'react';
import { useSelector } from 'react-redux';

const FIRST = 0;

export const useThirdStage = (): void => {
  const map = useSelector(mapDataSelector);
  const models = useSelector(modelsDataSelector);
  const backgrounds = useSelector(backgroundsDataSelector);
  const loadingCompleted = useSelector(mapLoadingAllStagesCompletedSelector);
  const handleMapChange = useHandleMapChange();

  const setDefaultMapModelData = useCallback(() => {
    const defaultBackground = backgrounds?.[FIRST];
    const defaultModel = models?.[FIRST];
    if (map.modelId || !defaultModel || !defaultBackground) {
      return;
    }

    handleMapChange({
      model: defaultModel,
      background: defaultBackground,
    });
  }, [backgrounds, models, map, handleMapChange]);

  useEffect(() => {
    if (!loadingCompleted) {
      return;
    }

    setDefaultMapModelData();
  }, [setDefaultMapModelData, loadingCompleted]);
};
