import Map from 'ol/Map';
import React, { MutableRefObject, useEffect, useState } from 'react';
import { MapInstance } from '../MapViewer.types';
import { useOlMapConfig } from './config/useOlMapConfig';
import { useOlMapInit } from './init/useOlMapInit';

interface UseOlMapInput {
  target?: HTMLElement;
}
interface UseOlMapOutput {
  mapRef: MutableRefObject<null | HTMLDivElement>;
  mapInstance: MapInstance;
}

type UseOlMap = (input?: UseOlMapInput) => UseOlMapOutput;

export const useOlMap: UseOlMap = ({ target } = {}) => {
  const mapRef = React.useRef<null | HTMLDivElement>(null);
  const [mapInstance, setMapInstance] = useState<MapInstance>(undefined);
  const mapConfig = useOlMapConfig();
  useOlMapInit();

  useEffect(() => {
    // checking if innerHTML is empty due to possibility of target element cloning by openlayers map instance
    if (!mapRef.current || mapRef.current.innerHTML !== '') {
      return;
    }

    const map = new Map({
      target: target || mapRef.current,
    });

    setMapInstance(currentMap => currentMap || map);
  }, [target]);

  useEffect(() => {
    if (!mapInstance) {
      return;
    }

    mapInstance.setView(mapConfig.view);
    mapInstance.setLayers(mapConfig.layers);
  }, [mapConfig, mapInstance]);

  return {
    mapRef,
    mapInstance,
  };
};
